==> hippoagentsdk-0.0.2-sources.jar: com/hippoagent/model/get_deal_info/Datum.java <==

package com.hippoagent.model.get_deal_info;

import java.util.List;
import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;

public class Datum {

    @SerializedName("deal_id")
    @Expose
    private Integer dealId;
    @SerializedName("assign_to")
    @Expose
    private String assignTo;
    @SerializedName("name")
    @Expose
    private String name;
    @SerializedName("stage")
    @Expose
    private String stage;
    @SerializedName("assign_name")
    @Expose
    private String assignName;
    @SerializedName("notes")
    @Expose
    private String notes;
    @SerializedName("contact_info")
    @Expose
    private List<ContactInfo> contactInfo = null;
    @SerializedName("organization_info")
    @Expose
    private List<OrganizationInfo> organizationInfo = null;
    @SerializedName("tags_data")
    @Expose
    private List<TagsDatum> tagsData = null;

    @SerializedName("ProspectID")
    @Expose
    private String ProspectID;
    @SerializedName("FirstName")
    @Expose
    private String FirstName;
    @SerializedName("Company")
    @Expose
    private String Company;

    @SerializedName("follower_data")
    @Expose
    private List<FollowerDatum> followerData = null;

    public List<FollowerDatum> getFollowerData() {
        return followerData;
    }

    public void setFollowerData(List<FollowerDatum> followerData) {
        this.followerData = followerData;
    }

    public String getProspectID() {
        return ProspectID;
    }

    public void setProspectID(String prospectID) {
        ProspectID = prospectID;
    }

    public String getFirstName() {
        return FirstName;
    }

    public void setFirstName(String firstName) {
        FirstName = firstName;
    }

    public String getCompany() {
        return Company;
    }

    public void setCompany(String company) {
        Company = company;
    }

    public Integer getDealId() {
        return dealId;
    }

    public void setDealId(Integer dealId) {
        this.dealId = dealId;
    }

    public String getAssignTo() {
        return assignTo;
    }

    public void setAssignTo(String assignTo) {
        this.assignTo = assignTo;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAssignName() {
        return assignName;
    }

    public void setAssignName(String assignName) {
        this.assignName = assignName;
    }

    public String getNotes() {
        return notes;
    }

    public void setNotes(String notes) {
        this.notes = notes;
    }

    public List<ContactInfo> getContactInfo() {
        return contactInfo;
    }

    public void setContactInfo(List<ContactInfo> contactInfo) {
        this.contactInfo = contactInfo;
    }

    public List<OrganizationInfo> getOrganizationInfo() {
        return organizationInfo;
    }

    public void setOrganizationInfo(List<OrganizationInfo> organizationInfo) {
        this.organizationInfo = organizationInfo;
    }

    public List<TagsDatum> getTagsData() {
        return tagsData;
    }

    public void setTagsData(List<TagsDatum> tagsData) {
        this.tagsData = tagsData;
    }

    public String getStage() {
        return stage;
    }

    public void setStage(String stage) {
        this.stage = stage;
    }
}

==> hippoagentsdk-3.0.5.1-sources.jar: com/hippoagent/model/get_deal_info/Datum.java <==

package com.hippoagent.model.get_deal_info;

import java.util.List;
import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;

public class Datum {

    @SerializedName("deal_id")
    @Expose
    private String dealId;
    @SerializedName("assign_to")
    @Expose
    private String assignTo;
    @SerializedName("name")
    @Expose
    private String name;
    @SerializedName("stage")
    @Expose
    private String stage;
    @SerializedName("assign_name")
    @Expose
    private String assignName;
    @SerializedName("notes")
    @Expose
    private String notes;
    @SerializedName("contact_info")
    @Expose
    private List<ContactInfo> contactInfo = null;
    @SerializedName("organization_info")
    @Expose
    private List<OrganizationInfo> organizationInfo = null;
    @SerializedName("tags_data")
    @Expose
    private List<TagsDatum> tagsData = null;

    @SerializedName("ProspectID")
    @Expose
    private String ProspectID;
    @SerializedName("FirstName")
    @Expose
    private String FirstName;
    @SerializedName("Company")
    @Expose
    private String Company;

    @SerializedName("follower_data")
    @Expose
    private List<FollowerDatum> followerData = null;

    public List<FollowerDatum> getFollowerData() {
        return followerData;
    }

    public void setFollowerData(List<FollowerDatum> followerData) {
        this.followerData = followerData;
    }

    public String getProspectID() {
        return ProspectID;
    }

    public void setProspectID(String prospectID) {
        ProspectID = prospectID;
    }

    public String getFirstName() {
        return FirstName;
    }

    public void setFirstName(String firstName) {
        FirstName = firstName;
    }

    public String getCompany() {
        return Company;
    }

    public void setCompany(String company) {
        Company = company;
    }

    public String getDealId() {
        return dealId;
    }

    public void setDealId(String dealId) {
        this.dealId = dealId;
    }

    public String getAssignTo() {
        return assignTo;
    }

    public void setAssignTo(String assignTo) {
        this.assignTo = assignTo;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAssignName() {
        return assignName;
    }

    public void setAssignName(String assignName) {
        this.assignName = assignName;
    }

    public String getNotes() {
        return notes;
    }

    public void setNotes(String notes) {
        this.notes = notes;
    }

    public List<ContactInfo> getContactInfo() {
        return contactInfo;
    }

    public void setContactInfo(List<ContactInfo> contactInfo) {
        this.contactInfo = contactInfo;
    }

    public List<OrganizationInfo> getOrganizationInfo() {
        return organizationInfo;
    }

    public void setOrganizationInfo(List<OrganizationInfo> organizationInfo) {
        this.organizationInfo = organizationInfo;
    }

    public List<TagsDatum> getTagsData() {
        return tagsData;
    }

    public void setTagsData(List<TagsDatum> tagsData) {
        this.tagsData = tagsData;
    }

    public String getStage() {
        return stage;
    }

    public void setStage(String stage) {
        this.stage = stage;
    }
}
